Module chewing::dictionary

source ·
Systems and user phrase dictionaries.

Structs

Enums

Traits

Type Aliases

  • A boxed iterator over all the entries in a dictionary.
  • A boxed iterator over the phrases and their frequency in a dictionary.