Struct chewing::dictionary::SystemDictionaryLoader
source · pub struct SystemDictionaryLoader { /* private fields */ }Expand description
Automatically searchs and loads system dictionaries.
Implementations
sourceimpl SystemDictionaryLoader
impl SystemDictionaryLoader
sourcepub fn new() -> SystemDictionaryLoader
pub fn new() -> SystemDictionaryLoader
Creates a new system dictionary loader.
sourcepub fn sys_path(self, path: impl Into<String>) -> SystemDictionaryLoader
pub fn sys_path(self, path: impl Into<String>) -> SystemDictionaryLoader
Override the default system dictionary search path.
sourcepub fn load(&self) -> Result<Vec<Box<dyn Dictionary>>, LoadDictionaryError>
pub fn load(&self) -> Result<Vec<Box<dyn Dictionary>>, LoadDictionaryError>
Searches and loads the system dictionaries and extra dictionaries.
If no dictionary were found, a builtn minimum dictionary will be loaded.
sourcepub fn load_abbrev(&self) -> Result<AbbrevTable, LoadDictionaryError>
pub fn load_abbrev(&self) -> Result<AbbrevTable, LoadDictionaryError>
Loads the abbrev table.
sourcepub fn load_symbol_selector(
&self,
) -> Result<SymbolSelector, LoadDictionaryError>
pub fn load_symbol_selector( &self, ) -> Result<SymbolSelector, LoadDictionaryError>
Loads the symbol table.