Module chewing::dictionary
source · Expand description
Systems and user phrase dictionaries.
Structs
- TODO: doc
- A collection of metadata of a dictionary.
- A collection of dictionaries that returns the union of the lookup results.
- A type containing a phrase string and its frequency.
- SqliteDictionary
sqliteTODO: doc - SqliteDictionaryBuilder
sqliteTODO: doc - A read-only dictionary using a pre-built Trie index that is both space efficient and fast to lookup.
- A builder to create a dictionary that can be loaded as a
Triedictionary. - A container for trie dictionary statistics.
- The error type which is returned from updating a dictionary.
Enums
- Errors during loading system or user dictionaries.
- SqliteDictionaryError
sqliteTODO: doc
Traits
- An interface for looking up dictionaries.
- TODO: doc
- An interface for updating dictionaries.
Type Aliases
- A boxed iterator over all the entries in a dictionary.
- A boxed iterator over the phrases and their frequency in a dictionary.